==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/da-DK/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tilbehør tjekket ind',
    'Accessory_Checkout_Notification' => 'Tilbehør tjekket ud',
    'Asset_Checkin_Notification' => 'Asset tjekket ind',
    'Asset_Checkout_Notification' => 'Aktiv tjekket ud',
    'Confirm_Accessory_Checkin' => 'Tilbehør checkin bekræftelse',
    'Confirm_Asset_Checkin' => 'Asset checkin bekræftelse',
    'Confirm_accessory_delivery' => 'Tilbehør leveringsbekræftelse',
    'Confirm_asset_delivery' => 'Asset leveringsbekræftelse',
    'Confirm_consumable_delivery' => 'Forbrugsvare leveringsbekræftelse',
    'Confirm_license_delivery' => 'Licens leveringsbekræftelse',
    'Consumable_checkout_notification' => 'Forbrugsstoffer tjekket ud',
    'Days' => 'Dage',
    'Expected_Checkin_Date' => 'Et asset tjekket ud til dig skal tjekkes tilbage den :date',
    'Expected_Checkin_Notification' => 'Påmindelse: :name checkin deadline nærmer sig',
    'Expected_Checkin_Report' => 'Forventet asset checkin rapport',
    'Expiring_Assets_Report' => 'Udløbsaktiver Rapport.',
    'Expiring_Licenses_Report' => 'Udløber Licenser Rapport.',
    'Item_Request_Canceled' => 'Elementforespørgsel annulleret',
    'Item_Requested' => 'Vareanmodning',
    'License_Checkin_Notification' => 'Licens tjekket ind',
    'License_Checkout_Notification' => 'Licens tjekket ud',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Lav lagerrapport',
    'a_user_canceled' => 'En bruger har annulleret en vareforespørgsel på hjemmesiden',
    'a_user_requested' => 'En bruger har anmodet om et emne på hjemmesiden',
    'acceptance_asset_accepted' => 'En bruger har accepteret et emne',
    'acceptance_asset_declined' => 'En bruger har afvist et emne',
    'accessory_name' => 'Tilbehør Navn',
    'additional_notes' => 'Yderligere bemærkninger',
    'admin_has_created' => 'En administrator har oprettet en konto til dig på webstedet:.',
    'asset' => 'Asset',
    'asset_name' => 'Aktivnavn',
    'asset_requested' => 'Aktiver bedt om',
    'asset_tag' => 'Inventarnummer',
    'assets_warrantee_alert' => 'Der er :count aktiv hvor garantien udløber indenfor de næste :threshold dage.|Der er :count aktiver hvor garantien udløber indenfor de næste :threshold dage.',
    'assigned_to' => 'Tildelt',
    'best_regards' => 'Med venlig hilsen,',
    'canceled' => 'annulleret',
    'checkin_date' => 'Tjekket Ind Dato',
    'checkout_date' => 'Checkout dato',
    'checkedout_from' => 'Tjekket ud fra',
    'checkedin_from'  => 'Tjekket ind fra',
    'checked_into' => 'Tjekket ind',
    'click_on_the_link_accessory' => 'Venligst klik på linket nederst for at bekræfte, at du har modtaget tilbehør.',
    'click_on_the_link_asset' => 'Klik venligst på linket nederst for at bekræfte, at du har modtaget aktivet.',
    'click_to_confirm' => 'Venligst klik på følgende link for at bekræfte din: web-konto:',
    'current_QTY' => 'Nuværende QTY',
    'days' => 'Dage',
    'expecting_checkin_date' => 'Forventet indtjekningsdato',
    'expires' => 'udløber',
    'hello' => 'Hej',
    'hi' => 'Hej',
    'i_have_read' => 'Jeg har læst og accepterer vilkårene for brug og har modtaget denne vare.',
    'inventory_report' => 'Lagerrapport',
    'item' => 'Emne',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Der er :count licens(er) der udløber indenfor den/de næste :threshold dag(e).',
    'link_to_update_password' => 'Venligst klik på følgende link for at opdatere din: webadgangskode:',
    'login' => 'Login',
    'login_first_admin' => 'Log ind på din nye Snipe-IT-installation ved hjælp af nedenstående referencer:',
    'low_inventory_alert' => 'Der er :count enhed som er under minimum lagertal eller som snart vil være det.|Der er :count enheder som er under minimum lagertal eller som snart vil være det.',
    'min_QTY' => 'Min QTY',
    'name' => 'Navn',
    'new_item_checked' => 'En ny vare er blevet tjekket ud under dit navn, detaljerne er nedenfor.',
    'notes' => 'Noter',
    'password' => 'Adgangskode',
    'password_reset' => 'Nulstil kodeord',
    'read_the_terms' => 'Læs venligst brugsbetingelserne nedenfor.',
    'read_the_terms_and_click' => 'Læs venligst vilkårene for brug nedenfor, og klik på linket nederst for at bekræfte, at du læser og accepterer vilkårene for brug, og har modtaget aktivet.',
    'requested' => 'Anmodet',
    'reset_link' => 'Din Password Reset Link',
    'reset_password' => 'Klik her for at nulstille adgangskoden:',
    'rights_reserved' => 'Alle rettigheder forbeholdt.',
    'serial' => 'Seriel',
    'snipe_webhook_test' => 'Snipe-IT-Integrationstest',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Resumé',
    'supplier' => 'Leverandør',
    'tag' => 'Mærkat',
    'test_email' => 'Test E-mail fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT Asset Management System. Hvis du fik dette, virker mailen :)',
    'the_following_item' => 'Følgende vare er blevet kontrolleret i:',
    'to_reset' => 'Nulstille din :web-adgangskode, udfylde denne formular:',
    'type' => 'Type',
    'upcoming-audits' => 'Der er :count asset, som skal tilses inden :threshold dage. |Der er :count assets, som skal tilses inden :threshold dage.',
    'user' => 'Bruger',
    'username' => 'Brugernavn',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Velkommen :navn',
    'welcome_to' => 'Velkommen til :web!',
    'your_assets' => 'Se dine assets',
    'your_credentials' => 'Dine Snipe-IT Legitimationsoplysninger',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/da-DK/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tilbehør tjekket ind',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'Tilbehør checkin bekræftelse',
    'Confirm_Asset_Checkin' => 'Asset checkin bekræftelse',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'Tilbehør leveringsbekræftelse',
    'Confirm_asset_delivery' => 'Asset leveringsbekræftelse',
    'Confirm_consumable_delivery' => 'Forbrugsvare leveringsbekræftelse',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'Licens leveringsbekræftelse',
    'Consumable_checkout_notification' => 'Forbrugsstoffer tjekket ud',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'Dage',
    'Expected_Checkin_Date' => 'Et asset tjekket ud til dig skal tjekkes tilbage den :date',
    'Expected_Checkin_Notification' => 'Påmindelse: :name checkin deadline nærmer sig',
    'Expected_Checkin_Report' => 'Forventet asset checkin rapport',
    'Expiring_Assets_Report' => 'Udløbsaktiver Rapport',
    'Expiring_Licenses_Report' => 'Udløber Licenser Rapport',
    'Item_Request_Canceled' => 'Elementforespørgsel annulleret',
    'Item_Requested' => 'Vareanmodning',
    'License_Checkin_Notification' => 'Licens tjekket ind',
    'License_Checkout_Notification' => 'Licens tjekket ud',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Lav lagerrapport',
    'a_user_canceled' => 'En bruger har annulleret en vareforespørgsel på hjemmesiden',
    'a_user_requested' => 'En bruger har anmodet om et emne på hjemmesiden',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'En bruger har accepteret et emne',
    'acceptance_asset_declined' => 'En bruger har afvist et emne',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'Tilbehør Navn',
    'additional_notes' => 'Yderligere bemærkninger',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'Asset',
    'asset_name' => 'Aktivnavn',
    'asset_requested' => 'Aktiver bedt om',
    'asset_tag' => 'Inventarnummer',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'Tildelt',
    'eol' => 'EOL',
    'best_regards' => 'Med venlig hilsen,',
    'canceled' => 'annulleret',
    'checkin_date' => 'Tjekket Ind Dato',
    'checkout_date' => 'Checkout dato',
    'checkedout_from' => 'Tjekket ud fra',
    'checkedin_from'  => 'Tjekket ind fra',
    'checked_into' => 'Tjekket ind',
    'click_on_the_link_accessory' => 'Venligst klik på linket nederst for at bekræfte, at du har modtaget tilbehør.',
    'click_on_the_link_asset' => 'Klik venligst på linket nederst for at bekræfte, at du har modtaget aktivet.',
    'click_to_confirm' => 'Venligst klik på følgende link for at bekræfte din: web-konto:',
    'current_QTY' => 'Nuværende QTY',
    'days' => 'Dage',
    'expecting_checkin_date' => 'Forventet indtjekningsdato',
    'expires' => 'udløber',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'Hej',
    'hi' => 'Hej',
    'i_have_read' => 'Jeg har læst og accepterer vilkårene for brug og har modtaget denne vare.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Lagerrapport',
    'item' => 'Emne',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'Venligst klik på følgende link for at opdatere din: webadgangskode:',
    'login' => 'Login',
    'login_first_admin' => 'Log ind på din nye Snipe-IT-installation ved hjælp af nedenstående referencer:',
    'low_inventory_alert' => 'Der er :count enhed som er under minimum lagertal eller som snart vil være det.|Der er :count enheder som er under minimum lagertal eller som snart vil være det.',
    'min_QTY' => 'Min QTY',
    'name' => 'Navn',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'An item was recently checked out under your name that requires acceptance, details are below.',
    'notes' => 'Noter',
    'password' => 'Adgangskode',
    'password_reset' => 'Nulstil kodeord',
    'read_the_terms' => 'Læs venligst brugsbetingelserne nedenfor.',
    'read_the_terms_and_click' => 'Læs venligst vilkårene for brug nedenfor, og klik på linket nederst for at bekræfte, at du læser og accepterer vilkårene for brug, og har modtaget aktivet.',
    'requested' => 'Anmodet',
    'reset_link' => 'Din Password Reset Link',
    'reset_password' => 'Klik her for at nulstille adgangskoden:',
    'rights_reserved' => 'Alle rettigheder forbeholdt.',
    'serial' => 'Seriel',
    'snipe_webhook_test' => 'Snipe-IT-Integrationstest',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Resumé',
    'supplier' => 'Leverandør',
    'tag' => 'Mærkat',
    'test_email' => 'Test E-mail fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT Asset Management System. Hvis du fik dette, virker mailen :)',
    'the_following_item' => 'Følgende vare er blevet kontrolleret i:',
    'to_reset' => 'Nulstille din :web-adgangskode, udfylde denne formular:',
    'type' => 'Type',
    'upcoming-audits' => 'Der er :count asset, som skal tilses inden :threshold dage. |Der er :count assets, som skal tilses inden :threshold dage.',
    'user' => 'Bruger',
    'username' => 'Brugernavn',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'Velkommen :navn',
    'welcome_to' => 'Velkommen til :web!',
    'your_assets' => 'Se dine assets',
    'your_credentials' => 'Dine Snipe-IT Legitimationsoplysninger',
    'mail_sent' => 'Mail sent successfully!',
];
